"use strict";
/* eslint-disable @typescript-eslint/no-var-requires */
Object.defineProperty(exports, "__esModule", { value: true });
exports.processArgv = exports.version = exports.usage = void 0;
const lib_1 = require("../lib");
const optionator = require('optionator');
const { parseArgv, generateHelp } = optionator({
    prepend: [
        `${lib_1.CLI_NAME} [options] [FILE ...]`,
        '        Format given file(s). If no files provided, read from STDIN.',
        '',
        `${lib_1.CLI_NAME} [options] DIR`,
        '        Format supported files under given directory.',
        '',
        `${lib_1.CLI_NAME} -c [options] FILE/DIR [FILE/DIR ...]`,
        '        Check if files (under directories) are formatted.',
    ].join('\n'),
    options: [
        {
            option: 'help',
            alias: 'h',
            type: 'Boolean',
            description: 'Show help.',
        },
        {
            option: 'version',
            alias: 'v',
            type: 'Boolean',
            description: 'Show version number.',
        },
        {
            option: 'log',
            alias: 'l',
            type: 'Boolean',
            description: 'Show debug logs.',
        },
        {
            option: 'check',
            alias: 'c',
            type: 'Boolean',
            description: 'Check if files/directories are formatted.',
        },
        {
            option: 'config',
            type: 'path::String',
            description: "Path to base config file, e.g. import-sorter.json. The formatted file's config will be merged into this base config.",
        },
        {
            option: 'force',
            alias: 'f',
            type: 'Boolean',
            description: 'Always format file(s) regardless of exclude config and file disable comments. Statement level disable comments will still work.',
        },
        {
            option: 'extension',
            alias: 'e',
            type: 'String',
            enum: ['ts', 'tsx', 'js', 'jsx', 'vue'],
            default: 'ts',
            description: 'File extension assumed when reading from STDIN and output file extension is unknown.',
        },
        {
            option: 'recursive',
            type: 'Boolean',
            default: 'true',
            description: 'Format directory recursively or not.',
        },
        {
            option: 'output',
            alias: 'o',
            type: 'path::String',
            description: 'Specify the output file or directory.',
        },
        {
            option: 'dry-run',
            alias: 'd',
            type: 'Boolean',
            description: 'Test running without changing any files.',
        },
    ],
});
function usage(code = 1) {
    const out = code === 0 ? process.stdout : process.stderr;
    out.write(`${generateHelp()}\n`);
    process.exit(code);
}
exports.usage = usage;
function version(code = 1) {
    const out = code === 0 ? process.stdout : process.stderr;
    out.write(`v${lib_1.VERSION}\n`);
    process.exit(code);
}
exports.version = version;
function processArgv(argv) {
    try {
        return parseArgv(argv);
    }
    catch (e) {
        const message = e instanceof Error ? e.message : `${e}`;
        process.stderr.write(message + '\n\n');
        usage();
        throw e; // Just to satisfy the compiler.
    }
}
exports.processArgv = processArgv;
//# sourceMappingURL=options.js.map