import { Configuration } from './types';
/**
 * Resolve config for a source file.
 *
 * The following sources will be considered if found (in precedence from high to low):
 * - [ESLint configuration](https://eslint.org/docs/user-guide/configuring)
 * - `"importSorter"` section in `package.json`
 * - `import-sorter.json` (File name is configurable from the base config)
 * - [Prettier configuration](https://github.com/prettier/prettier-vscode#configuration)
 * - `.editorconfig`
 * - The base config provided as parameter
 *
 * @typeparam T - A type extended from Configuration
 *
 * @param fileName - Source file name
 * @param config - Base config
 */
export declare function loadImportSorterConfig<T extends Configuration = Configuration>(fileName: string, config?: T): T;
export declare function enhanceEol<T extends Configuration>(config: T, detectEol: () => string): T;
/**
 * Load config from given file, e.g. _path/to/import-sorter.json_.
 *
 * Will throw an error if file is unreadable or content is not a valid JSON object.
 */
export declare function loadConfigFromJsonFile(fileName: string): Configuration;
