"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isFileExcludedByConfig = exports.resolveConfigForSource = exports.resolveConfigForFile = exports.loadConfigFromJsonFile = void 0;
const minimatch_1 = __importDefault(require("minimatch"));
const end_of_line_1 = require("@dozerg/end-of-line");
const importSorter_1 = require("./importSorter");
__exportStar(require("./types"), exports);
__exportStar(require("./merge"), exports);
var importSorter_2 = require("./importSorter");
Object.defineProperty(exports, "loadConfigFromJsonFile", { enumerable: true, get: function () { return importSorter_2.loadConfigFromJsonFile; } });
Object.defineProperty(exports, "resolveConfigForFile", { enumerable: true, get: function () { return importSorter_2.loadImportSorterConfig; } });
/**
 * Resolve config for given source text.
 *
 * This function will detect EOL for the text and update the base config provided.
 *
 * @typeparam T - A type extended from Configuration
 *
 * @param text - Source text
 * @param config - Base config
 */
function resolveConfigForSource(text, config) {
    return (0, importSorter_1.enhanceEol)(config ?? {}, () => (0, end_of_line_1.endOfLine)(text));
}
exports.resolveConfigForSource = resolveConfigForSource;
/**
 * Test if a file is excluded by the given config, taking `config.force` flag into account.
 *
 * The file name will be normalized to use `/` as path separator before matching.
 */
function isFileExcludedByConfig(fileName, config) {
    const { exclude, excludeGlob, force } = config;
    if (force)
        return false;
    // glob
    for (const p of excludeGlob ?? [])
        if ((0, minimatch_1.default)(fileName, p, { matchBase: true }))
            return true;
    // regex
    const normalized = fileName.replace(/\\/g, '/');
    for (const p of exclude ?? []) {
        const r = new RegExp(p);
        if (r.test(fileName) || r.test(normalized))
            return true;
    }
    return false;
}
exports.isFileExcludedByConfig = isFileExcludedByConfig;
//# sourceMappingURL=index.js.map