"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadPretConfig = void 0;
const prettier_1 = __importDefault(require("prettier"));
const require_module_1 = __importDefault(require("@dozerg/require-module"));
const common_1 = require("../common");
// https://prettier.io/docs/en/options.html
function loadPretConfig(fileName) {
    const log = (0, common_1.logger)('format-imports.loadPretConfig');
    log.debug('Loading Prettier/EditorConfig config for fileName:', fileName);
    try {
        const pt = (0, require_module_1.default)('prettier', fileName, prettier_1.default);
        log.debug('Prettier API version:', pt.version);
        const config = pt.resolveConfig.sync(fileName, { useCache: false, editorconfig: true });
        log.debug('Prettier config:', config);
        if (!config)
            return {};
        const { printWidth, useTabs, tabWidth, semi, singleQuote, trailingComma, bracketSpacing,
        // endOfLine,
         } = config;
        return {
            maxLineLength: printWidth ?? 80,
            tabType: useTabs ? 'tab' : 'space',
            tabSize: tabWidth ?? 2,
            hasSemicolon: semi ?? true,
            quoteMark: singleQuote ? 'single' : 'double',
            trailingComma: trailingComma === 'none' ? 'none' : 'multiLine',
            bracketSpacing: bracketSpacing ?? true,
            // eol: endOfLine === 'lf' ? 'LF' : endOfLine === 'crlf' ? 'CRLF' : undefined,
            insertFinalNewline: true, // Prettier always enables it.
        };
    }
    catch (e) {
        const msg = e instanceof Error ? e.message : `${e}`;
        log.warn('Failed to load Prettier/EditorConfig config for filename:', fileName, 'with error:', msg);
        return {};
    }
}
exports.loadPretConfig = loadPretConfig;
//# sourceMappingURL=prettier.js.map