"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const condition_1 = require("@dozerg/condition");
class ComposeResult {
    constructor(lines = [], wrapped = true, trailing = 0) {
        this.lines = lines;
        this.wrapped = wrapped;
        this.trailing = trailing;
    }
    get level() {
        if (this.lines.length < 1)
            return 0;
        return this.lines[this.lines.length - 1].level;
    }
    get empty() {
        return this.lines.length < 1;
    }
    text(config) {
        return this.lines.map(l => l.text(config)).join(config.nl);
    }
    merge(other, { tabw, maxLength }, last) {
        if (other.lines.length < 1)
            return { result: this };
        const { lines: newLines, line, only } = this.mergeLines(other.lines);
        const trailing = last && only ? this.trailing + other.trailing : 0;
        const needWrap = line.length(tabw) + trailing > maxLength;
        const result = new ComposeResult(newLines, other.wrapped, trailing);
        return { result, needWrap };
    }
    mergeLines(other) {
        (0, condition_1.assertTrue)(other.length > 0);
        if (this.lines.length < 1)
            return { lines: other, line: other[0], only: other.length < 2 };
        const last = this.lines[this.lines.length - 1];
        const [next, ...rest] = other;
        const line = last.merge(next);
        return {
            lines: [...this.lines.slice(0, this.lines.length - 1), line, ...rest],
            line,
            only: rest.length < 1,
        };
    }
}
exports.default = ComposeResult;
//# sourceMappingURL=ComposeResult.js.map