"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const condition_1 = require("@dozerg/condition");
const no_new_1 = __importDefault(require("@dozerg/no-new"));
const ComposeLine_1 = __importDefault(require("./ComposeLine"));
const ComposeResult_1 = __importDefault(require("./ComposeResult"));
class NamedPart {
    constructor(names, from, maxWords, noWrapSingle) {
        this.from = from;
        this.maxWords = maxWords;
        this.noWrapSingle = noWrapSingle;
        this.names = names.map(composeName);
    }
    compose(level, config) {
        (0, condition_1.assertTrue)(this.maxWords >= 1);
        const { bracket, sComma } = config;
        if (0 < this.names.length && this.names.length <= this.maxWords) {
            const n = bracket(`${this.names.join(', ')}${sComma}`);
            const line = new ComposeLine_1.default(level, join(n, this.from));
            return new ComposeResult_1.default([line], this.noWrapSingle && this.names.length === 1);
        }
        return this.composeWrap(level, config);
    }
    composeWrap(level, config) {
        if (this.names.length < 1) {
            const line = new ComposeLine_1.default(level, join('{}', this.from));
            return new ComposeResult_1.default([line], true);
        }
        else if (this.noWrapSingle && this.names.length === 1)
            return this.compose(level, config);
        const lines = [];
        for (let n = this.names; n.length;) {
            const { line, left } = composeLine(level + 1, n, config);
            lines.push(line);
            n = left;
        }
        const s = new ComposeLine_1.default(level, '{');
        const e = new ComposeLine_1.default(level, join('}', this.from));
        return new ComposeResult_1.default([s, ...lines, e], true);
    }
}
function composeName(name) {
    const { propertyName, aliasName, isTypeOnly } = name;
    const type = isTypeOnly ? 'type ' : '';
    if (propertyName) {
        const name = aliasName ? `${propertyName} as ${aliasName}` : propertyName;
        return type + name;
    }
    (0, condition_1.assertNonNull)(aliasName);
    return `* as ${aliasName}`;
}
function composeLine(level, names, { wrap, tabw, mComma, maxLength }) {
    const { length: len } = names;
    (0, condition_1.assertTrue)(len > 0);
    let i = 1;
    for (let sz = tabw * level + names[0].length; i < len && i < wrap.perLine; ++i) {
        const n = sz + 2 + names[i].length;
        if (n + (i + 1 < len ? 1 : mComma.length) > maxLength)
            break;
        sz = n;
    }
    return {
        line: new ComposeLine_1.default(level, names.slice(0, i).join(', ') + (i < len ? ',' : mComma)),
        left: names.slice(i),
    };
}
function join(...arr) {
    return arr.filter(s => !!s).join(' ');
}
exports.default = (0, no_new_1.default)(NamedPart);
//# sourceMappingURL=NamedPart.js.map