import { type Linter } from 'eslint';
import { type UnionToIntersection } from 'utility-types';
import { type Configuration } from '../../../config';
export type Rules = Required<Linter.Config>['rules'];
/**
 * Extract options for ESLint rules.
 * All rules should have the same options structure, e.g. indent and \@typescript-eslint/indent
 * @returns The resolved options of the rules specified by _keys_.
 */
export declare function extractOptions<Options>(config: Configuration, rules: Rules, defaultOptions: Options, ...keys: string[]): (Options & {}) | undefined;
/**
 * A translator is a function receives a `Configuration` and ESLint `Rules`,
 * and returns the new `config` and `processed` data if there are any.
 */
type Translator<P extends object> = (config: Configuration, rules: Rules, funcName: string) => {
    config: Configuration;
    processed?: P;
};
/**
 * Infer processed data type from translators.
 */
type ProcessedAsUnion<T> = T extends Translator<infer P>[] ? P : never;
/**
 * Given a number of translators, infer the processed data type.
 */
type Processed<T extends Translator<any>[]> = Partial<UnionToIntersection<ProcessedAsUnion<T>>>;
/**
 * Apply a number of `translators` to `config`.
 *
 * @param config - The original configuration
 * @param rules - ESLint rules
 * @param translators - An array of translations.
 * @returns The updated config and processed data if there are any
 */
export declare function apply<T extends Translator<any>[]>(config: Configuration, rules: Rules, ...translators: T): {
    config: Configuration;
    processed?: Processed<T>;
};
export {};
