"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.enhanceWithEslint = void 0;
const eslint_1 = __importDefault(require("eslint"));
const require_module_1 = __importDefault(require("@dozerg/require-module"));
const common_1 = require("../../../common");
const helper_1 = require("./helper");
const comma_dangle_1 = require("./rules/comma-dangle");
const eol_last_1 = require("./rules/eol-last");
const newline_after_import_1 = require("./rules/import/newline-after-import");
const no_useless_path_segments_1 = require("./rules/import/no-useless-path-segments");
const indent_1 = require("./rules/indent");
const max_len_1 = require("./rules/max-len");
const object_curly_spacing_1 = require("./rules/object-curly-spacing");
const semi_1 = require("./rules/semi");
const sort_imports_1 = require("./rules/sort-imports");
async function enhanceWithEslint(config, fileName, configPath) {
    const rules = (await loadESLintConfig(fileName, configPath))?.rules;
    if (!rules)
        return { config };
    return (0, helper_1.apply)(config, rules, sort_imports_1.translateSortImportsRule, newline_after_import_1.translateNewlineAfterImportRule, no_useless_path_segments_1.translateNoUselessPathSegmentsRule, max_len_1.translateMaxLenRule, indent_1.translateIndentRule, eol_last_1.translateEolLastRule, semi_1.translateSemiRule, comma_dangle_1.translateCommaDangleRule, object_curly_spacing_1.translateObjectCurlySpacingRule);
}
exports.enhanceWithEslint = enhanceWithEslint;
async function loadESLintConfig(fileName, configFile) {
    const log = (0, common_1.logger)('format-imports.loadESLintConfig');
    log.debug('Loading ESLint config for fileName:', fileName, 'from', configFile ?? 'default');
    try {
        const { ESLint } = (0, require_module_1.default)('eslint', fileName, eslint_1.default);
        if (!ESLint) {
            log.warn('Cannot find class "ESLint". Maybe ESLint is too old.');
            return undefined;
        }
        log.debug('ESLint API version:', ESLint.version);
        const esl = new ESLint({ overrideConfigFile: configFile });
        if (await esl.isPathIgnored(fileName)) {
            log.debug('Ignored by ESLint for fileName:', fileName);
            return undefined;
        }
        return (await esl.calculateConfigForFile(fileName));
    }
    catch (e) {
        const msg = e instanceof Error ? e.message : `${e}`;
        log.warn('Failed to load ESLint config for fileName:', fileName, 'with error:', msg);
        return undefined;
    }
}
//# sourceMappingURL=index.js.map