"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.translateSortImportsRule = void 0;
const config_1 = require("../../../../config");
const helper_1 = require("../helper");
const DEFAULT_OPTIONS = {
    ignoreCase: false,
    ignoreDeclarationSort: false,
    ignoreMemberSort: false,
    memberSyntaxSortOrder: Array('none', 'all', 'multiple', 'single'),
    allowSeparatedGroups: false,
};
function translateSortImportsRule(config, rules) {
    const options = (0, helper_1.extractOptions)(config, rules, DEFAULT_OPTIONS, 'sort-imports');
    return options === undefined ? { config } : process(config, options);
}
exports.translateSortImportsRule = translateSortImportsRule;
function process(config, options) {
    const sortImportsBy = calcSortImportsBy(options);
    const sortRules = calcSortRules(options);
    const aliasFirst = !!sortRules;
    const ignoreSorting = !!sortImportsBy || !!sortRules;
    const { groupRules, groupOrder } = calcGroupRules(options);
    const c = (0, config_1.mergeConfig)(config, { sortImportsBy, sortRules, groupRules });
    return { config: c, processed: { groupOrder, ignoreSorting, aliasFirst } };
}
function calcSortImportsBy({ ignoreDeclarationSort }) {
    return ignoreDeclarationSort ? undefined : 'names';
}
function calcSortRules({ ignoreCase, ignoreDeclarationSort, ignoreMemberSort }) {
    if (ignoreDeclarationSort && ignoreMemberSort)
        return undefined;
    const names = ignoreCase ? ['_', 'aA'] : ['AZ', '_'];
    return { names };
}
function calcGroupRules({ memberSyntaxSortOrder, allowSeparatedGroups, ignoreDeclarationSort, }) {
    if (ignoreDeclarationSort)
        return {};
    const groupOrder = memberSyntaxSortOrder.map(v => {
        switch (v) {
            case 'none':
                return 'scripts';
            case 'all':
                return 'namespace';
            case 'multiple':
                return 'multiple';
            case 'single':
                return 'single';
        }
    });
    return allowSeparatedGroups
        ? { groupOrder }
        : { groupRules: groupOrder.map(g => ({ flags: g })) };
}
//# sourceMappingURL=sort-imports.js.map