"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadTsConfig = void 0;
const node_path_1 = __importDefault(require("node:path"));
const node_cache_1 = __importDefault(require("node-cache"));
const typescript_1 = __importDefault(require("typescript"));
const condition_1 = require("@dozerg/condition");
const require_module_1 = __importDefault(require("@dozerg/require-module"));
const common_1 = require("../../common");
const CACHE = new node_cache_1.default({ stdTTL: 5 });
function loadTsConfig(fileName, configPath) {
    const log = (0, common_1.logger)('format-imports.loadTsConfig');
    log.debug('Loading TS config for fileName:', fileName, 'from', configPath ?? 'default');
    try {
        const { findConfigFile, readConfigFile, parseJsonConfigFileContent, sys, version } = (0, require_module_1.default)('typescript', fileName, typescript_1.default);
        log.debug('TypeScript API version:', version);
        const configFile = configPath || findConfigFile(fileName, sys.fileExists.bind(sys));
        if (!configFile)
            return undefined;
        const opt = CACHE.get(configFile);
        if ((0, condition_1.isObject)(opt))
            return opt;
        log.debug('Loading TS config from:', configFile);
        const { config } = readConfigFile(configFile, sys.readFile.bind(sys));
        const { options } = parseJsonConfigFileContent(config, sys, node_path_1.default.dirname(configFile));
        CACHE.set(configFile, options);
        return options;
    }
    catch (e) {
        const msg = e instanceof Error ? e.message : `${e}`;
        log.warn('Failed to load TS config for fileName:', fileName, 'with error:', msg);
        return undefined;
    }
}
exports.loadTsConfig = loadTsConfig;
//# sourceMappingURL=tsconfig.js.map