import { type ComposeConfig } from '../config';
import { type RangeAndEmptyLines } from '../types';
import { type Edit } from './types';
interface InsertText {
    text?: string;
    minLeadingNewLines?: number;
    minTrailingNewLines?: number;
}
interface EditBlock extends InsertText {
    range: RangeAndEmptyLines;
}
/**
 * Manage edits (insert/delete/replace).
 *
 * When calculating number of newlines, please note that:
 * - 0 newlines means statements are in the same line;
 * - 1 newline means statements are in consecutive lines;
 * - 2 newlines means there is ONE empty line between statements;
 * - and so on.
 */
export default class EditManager {
    private readonly ranges_;
    /**
     * Initialize the object with all the statements to delete.
     *
     * Internally, statements are converted to `RangeBlock`.
     * `RangeBlock`s will be sorted and merged if overlapping or consecutive.
     */
    constructor(statements: {
        range: RangeAndEmptyLines;
    }[]);
    empty(): boolean;
    /**
     * Add an edit (insert/delete/replace) to the internal `RangeBlock`s.
     *
     * If it's within a `RangeBlock`, it will be added.
     *
     * Otherwise a new `RangeBlock` will be created to hold the edit.
     */
    insert(edit: EditBlock): void;
    /**
     * Translate internal range blocks into `Edit`s.
     */
    generateEdits(config: ComposeConfig): Edit[];
}
export {};
