"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.apply = void 0;
/**
 * Apply `edits`(insert/replace/delete) to `sourceText` from `sourceFile`.
 *
 * @returns New source text, or `undefined` if nothing changes.
 */
function apply(sourceText, sourceFile, edits) {
    if (edits.length < 1)
        return undefined;
    const sortedEdits = edits.sort(({ range: r1 }, { range: r2 }) => r1.start.pos - r2.start.pos);
    let text = '';
    let cur = 0;
    sortedEdits.forEach(({ range, newText }) => {
        const { start, end } = range;
        const pos = sourceFile.getPositionOfLineAndCharacter(start.line, start.character);
        if (cur < pos)
            text += sourceText.slice(cur, pos);
        text += newText;
        cur = Math.max(cur, sourceFile.getPositionOfLineAndCharacter(end.line, end.character));
    });
    text += sourceText.slice(cur);
    return text === sourceText ? undefined : text;
}
exports.apply = apply;
//# sourceMappingURL=apply.js.map