"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatSource = void 0;
const typescript_1 = __importStar(require("typescript"));
const common_1 = require("../../common");
const edit_1 = require("../edit");
const parser_1 = require("../parser");
const sort_1 = require("../sort");
const keep_1 = require("./keep");
function formatSource(text, fileName, { config, tsCompilerOptions, processed, composeConfig }) {
    const log = (0, common_1.logger)('format-imports.formatSource');
    log.info('Formatting', fileName, 'with enhanced config:', config);
    log.debug('tsCompilerOptions:', tsCompilerOptions);
    log.debug('ESLint config processed:', processed);
    log.debug('composeConfig:', composeConfig);
    const sourceFile = typescript_1.default.createSourceFile(fileName, text, typescript_1.ScriptTarget.Latest);
    // 34%
    const { importNodes, importsInsertPoint: point, exportNodes, allIds, unhandled, } = (0, parser_1.parseSource)(sourceFile, text, config, tsCompilerOptions);
    // 39%
    const editManager = new edit_1.EditManager([...importNodes, ...exportNodes]);
    if (editManager.empty())
        return undefined;
    const unusedIds = () => (0, parser_1.getUnusedIds)(allIds, importNodes, fileName, sourceFile, tsCompilerOptions);
    const sorter = (0, sort_1.sorterFromRules)(config.sortRules);
    const result = formatImports(importNodes, point, unusedIds, config, composeConfig, sorter, processed);
    // 88%
    if (result && point)
        editManager.insert({ range: point, text: result, minTrailingNewLines: composeConfig.groupEnd });
    const isModule = unhandled > 0 || !!result; // If there are import/export declarations, it is a module.
    const edits = formatExports(exportNodes, composeConfig, sorter, isModule);
    edits.forEach(e => editManager.insert(e));
    return (0, edit_1.apply)(text, sourceFile, editManager.generateEdits(composeConfig));
}
exports.formatSource = formatSource;
function formatImports(importNodes, insertPoint, unusedIds, config, composeConfig, sorter, eslintProcessed) {
    if (!insertPoint || !importNodes.length)
        return undefined;
    const groups = (0, sort_1.sortImports)(importNodes, unusedIds(), config, sorter, eslintProcessed);
    const { groupSep } = composeConfig;
    return groups.compose(composeConfig, groupSep);
}
function formatExports(exportNodes, composeConfig, sorter, isModule) {
    if (!exportNodes.length)
        return [];
    const sorted = (0, sort_1.sortExports)(exportNodes, sorter.compareNames);
    const filtered = sorted.filter(n => !n.empty());
    const nodes = filtered.length > 0 || isModule ? filtered : (0, keep_1.decideKeep)(sorted);
    return nodes.map(n => ({ range: n.range, text: n.compose(composeConfig) }));
}
//# sourceMappingURL=format.js.map