import { type Configuration } from '../../config';
import { type FormatOptions } from '../config';
/**
 * A type representing file extensions supported.
 */
export type Extension = 'js' | 'ts' | 'jsx' | 'tsx' | 'vue';
/**
 * File extensions supported.
 */
export declare const SUPPORTED_EXTENSIONS: Extension[];
/**
 * Format given source text from a file, asynchronously.
 *
 * This function will try to find _tsconfig.json_ and ESLint config relating to the source file,
 * and merge them to the base config provided.
 *
 * `options` can be used to change _tsconfig.json_ and ESLint config loading behavior for testing
 * purpose.
 *
 * @see {@link formatSourceFromFile.sync}
 *
 * @param text - Source text
 * @param fileName - Source file name
 * @param config - Base config
 * @param options - Internal/testing options
 *
 * @returns Promise of the result text or `undefined` if nothing changes.
 */
export declare function formatSourceFromFile(text: string, fileName: string, config: Configuration, options?: FormatOptions): Promise<string | undefined>;
export declare namespace formatSourceFromFile {
    var sync: (text: string, fileName: string, config: Configuration, options?: FormatOptions | undefined) => string | undefined;
}
/**
 * Format given source text without knowing the source file, asynchronously.
 *
 * This function will try to find _tsconfig.json_ and ESLint config relating to the source file,
 * and merge them to the base config provided.
 *
 * `options` can be used to change _tsconfig.json_ and ESLint config loading behavior for testing
 * purpose.
 *
 * @see {@link formatSourceWithoutFile.sync}
 *
 * @param text - Source text
 * @param extension - File extension to reveal the source language
 * @param config - Base config
 * @param options - Internal/testing options
 *
 * @returns Promise of the result text or `undefined` if nothing changes.
 */
export declare function formatSourceWithoutFile(text: string, extension: Extension, config: Configuration, options?: FormatOptions): Promise<string | undefined>;
export declare namespace formatSourceWithoutFile {
    var sync: (text: string, extension: Extension, config: Configuration, options?: FormatOptions | undefined) => string | undefined;
}
