"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatVueSource = void 0;
const compiler_sfc_1 = require("@vue/compiler-sfc");
const index_1 = require("../../index");
const format_1 = require("./format");
async function formatVueSource(text, fileName, allConfig) {
    const { descriptor } = (0, compiler_sfc_1.parse)(text);
    const vueScript = descriptor.scriptSetup ?? descriptor.script;
    if (!vueScript)
        return undefined;
    const { supported, ext } = checkLang(vueScript.lang);
    if (!supported)
        return undefined;
    const head = text.slice(0, vueScript.loc.start.offset);
    const originScript = vueScript.content;
    const tail = text.slice(vueScript.loc.end.offset);
    // Disable removing unused names because imports can be used outside of <script> in Vue.
    // See https://vuejs.org/api/sfc-script-setup.html#using-components
    const config = (0, index_1.mergeConfig)(allConfig.config, { keepUnused: ['.*'] });
    const sortedScript = await (0, format_1.formatSource)(originScript, fileName + ext, { ...allConfig, config });
    if (sortedScript === undefined)
        return wrapScript(head, originScript, tail, allConfig.composeConfig);
    return wrapScript(head, sortedScript, tail, allConfig.composeConfig);
}
exports.formatVueSource = formatVueSource;
function checkLang(lang) {
    const SUPPORTED_LANG = ['js', 'ts', 'jsx', 'tsx'];
    if (!lang)
        return { supported: true, ext: '.js' };
    return { supported: SUPPORTED_LANG.includes(lang), ext: '.' + lang };
}
function wrapScript(head, script, tail, { nl }) {
    if (!script)
        return head + tail; // <script></script>
    /**
     * <script>
     * xxx
     * </script>
     */
    if (script.endsWith(nl))
        return head + nl + script + tail;
    return head + nl + script + nl + tail;
}
//# sourceMappingURL=vue.js.map