"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_1 = require("typescript");
const compose_1 = require("../compose");
const helper_1 = require("./helper");
const path_1 = require("./path");
const Statement_1 = __importDefault(require("./Statement"));
class ExportNode extends Statement_1.default {
    static fromDecl(node, args) {
        const { exportClause, moduleSpecifier, isTypeOnly } = node;
        if (!exportClause || exportClause.kind !== typescript_1.SyntaxKind.NamedExports)
            return undefined;
        const names = exportClause.elements
            .filter(e => e.kind === typescript_1.SyntaxKind.ExportSpecifier)
            .map(helper_1.getNameBinding);
        if (moduleSpecifier && moduleSpecifier.kind !== typescript_1.SyntaxKind.StringLiteral)
            return undefined;
        const moduleIdentifier = moduleSpecifier && moduleSpecifier.text;
        return new ExportNode(moduleIdentifier, names, args, isTypeOnly);
    }
    constructor(moduleIdentifier, names, args, isTypeOnly) {
        super(args);
        this.moduleIdentifier_ = moduleIdentifier && (0, path_1.normalizePath)(moduleIdentifier, args.config);
        this.isTypeOnly_ = isTypeOnly;
        this.names = names;
    }
    hasModuleIdentifier() {
        return !!this.moduleIdentifier_;
    }
    empty() {
        return this.names.length < 1;
    }
    merge(node) {
        if (
        // this.empty() ||
        this.moduleIdentifier_ !== node.moduleIdentifier_ ||
            this.isTypeOnly_ !== node.isTypeOnly_ ||
            !this.canMergeComments(node))
            return false;
        this.names.push(...node.names);
        node.names = [];
        return this.mergeComments(node);
    }
    compose(config) {
        const { leadingText, followingNewLines, trailingText, tailingLength } = this.composeComments(config);
        const nl = (followingNewLines ?? 0) > 1 ? config.nl : '';
        const importText = this.composeExport(tailingLength, config);
        return leadingText + nl + importText + trailingText;
    }
    composeExport(commentLength, config) {
        const { quote, wrap } = config;
        const verb = 'export' + (this.isTypeOnly_ ? ' type' : '');
        const path = this.moduleIdentifier_;
        const from = path ? 'from ' + quote(path) : undefined;
        const maxWords = wrap.exported;
        return (0, compose_1.composeParts)([
            (0, compose_1.StringPart)(verb),
            (0, compose_1.NamedPart)(this.names, from, maxWords, !wrap.parts),
            (0, compose_1.SemiPart)(commentLength),
        ], config);
    }
}
exports.default = ExportNode;
//# sourceMappingURL=ExportNode.js.map