import { type ImportDeclaration, type ImportEqualsDeclaration } from 'typescript';
import { type FlagSymbol } from '../../config';
import { type ComposeConfig } from '../config';
import type { Binding } from '../types';
import type KeepUnused from './KeepUnused';
import Statement, { type StatementArgs } from './Statement';
import { type NameUsage } from './unused';
export default class ImportNode extends Statement {
    private readonly node_;
    readonly moduleIdentifier: string;
    private readonly isScript;
    readonly isTypeOnly: boolean;
    private defaultName_?;
    private binding_?;
    private readonly assertEntries?;
    static fromDecl(node: ImportDeclaration, args: StatementArgs): ImportNode | undefined;
    static fromEqDecl(node: ImportEqualsDeclaration, args: StatementArgs): ImportNode | undefined;
    private constructor();
    get defaultName(): string | undefined;
    get binding(): Binding | undefined;
    get flagType(): FlagSymbol;
    get isBuiltIn(): boolean;
    matchPath(regex: RegExp): boolean;
    allNames(): string[];
    empty(): boolean;
    removeUnusedNames(usage: NameUsage, keepUnused?: KeepUnused): void;
    /**
     * @returns true if `node` is fully merged to `this`;
     *          false if `node` still has names or comments thus can't be ignored.
     */
    merge(node: ImportNode): boolean;
    checkBindingDefault(): void;
    compose(config: ComposeConfig): string;
    private removeBindingDefault;
    /**
     * Find and remove 'default as X' from binding names and returns 'X'.
     *
     * If whenSingle is true and names array length is not 1, do nothing.
     */
    private pickBindingDefault;
    private mergeBinding;
    private mergeDefaultName;
    private composeImport;
    private composeEqDecl;
    /**
     * Script import:
     * ```
     *    import 'A';
     * ```
     *
     * Default import:
     * ```
     *    import A from 'B';
     * ```
     *
     * Binding names import:
     * ```
     *    import { A, B as C } from 'D';
     *    import {
     *      A, B,
     *      C as D,
     *    } from 'E';
     * ```
     *
     * Namespace import:
     * ```
     *    import * as A from 'B';
     * ```
     *
     * Mixed examples:
     * ```
     *    import A, { B, C } from 'D';
     *    import A, {
     *      B,
     *      C as D,
     *      E,
     *    } from 'F';
     *    import A, * as B from 'C';
     *    import A, { default as B, C, D } from 'E';
     * ```
     *
     * With assert clause
     * ```
     *    import A from 'a' assert { type: 'json' };
     * ```
     */
    private composeDecl;
}
