"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const condition_1 = require("@dozerg/condition");
const compose_1 = require("../compose");
class Statement {
    constructor(args) {
        this.range = args.range;
        this.leadingComments_ = args.leadingComments;
        this.trailingCommentsText_ = args.trailingCommentsText;
    }
    withinDeclRange(pos) {
        const { start, end } = this.range;
        return start.pos <= pos && pos < end.pos;
    }
    hasComments() {
        return this.hasLeadingComments || this.hasTrailingComments;
    }
    get hasLeadingComments() {
        return !!this.leadingComments_ && this.leadingComments_.length > 0;
    }
    get hasTrailingComments() {
        return !!this.trailingCommentsText_;
    }
    composeComments(config) {
        const leadingText = (0, compose_1.composeComments)(this.leadingComments_, config) ?? '';
        const followingNewLines = this.leadingComments_?.slice(-1)[0]?.trailingNewLines;
        const trailingText = this.trailingCommentsText_;
        const tailingLength = config.wrap.skipCmt ? 0 : trailingText.split(/\r?\n/)?.[0]?.length ?? 0;
        return { leadingText, followingNewLines, trailingText, tailingLength };
    }
    canMergeComments(node) {
        return !((this.hasLeadingComments && node.hasLeadingComments) ||
            (this.hasTrailingComments && node.hasTrailingComments));
    }
    mergeComments(node) {
        (0, condition_1.assertTrue)(this.canMergeComments(node));
        if (!this.leadingComments_)
            this.leadingComments_ = node.leadingComments_;
        if (!this.trailingCommentsText_)
            this.trailingCommentsText_ = node.trailingCommentsText_;
        node.leadingComments_ = undefined;
        node.trailingCommentsText_ = '';
        return true;
    }
}
exports.default = Statement;
//# sourceMappingURL=Statement.js.map