"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeNodeProtocol = exports.removeLastIndex = exports.removeLastSlash = exports.normalize = exports.normalizePath = void 0;
const node_path_1 = __importDefault(require("node:path"));
const is_builtin_module_1 = __importDefault(require("is-builtin-module"));
const condition_1 = require("@dozerg/condition");
const NODE_PROTOCOL = 'node:';
function normalizePath(path, options) {
    const { removeLastSlashInPath, removeLastIndexInPath, nodeProtocol } = options ?? {};
    const npFn = nodeProtocol === 'always'
        ? addNodeProtocol
        : nodeProtocol === 'none'
            ? removeNodeProtocol
            : undefined;
    return apply(path, normalize, [removeLastIndex, removeLastIndexInPath], [removeLastSlash, removeLastSlashInPath], [npFn, (0, is_builtin_module_1.default)(path)]);
}
exports.normalizePath = normalizePath;
// Exported for testing purpose.
function normalize(str) {
    if (!str)
        return '';
    const r = node_path_1.default.normalize(str.replace(/\\/g, '/')).replace(/\\/g, '/');
    return !str.startsWith('.')
        ? r
        : !r.startsWith('.')
            ? './' + r
            : r === '.'
                ? './'
                : r.endsWith('..')
                    ? r + '/'
                    : r;
}
exports.normalize = normalize;
const PATTERNS = ['index', 'index.js', 'index.jsx', 'index.ts', 'index.tsx'];
// Exported for testing purpose.
function removeLastSlash(str) {
    if (!str || str === '/' || !str.endsWith('/'))
        return str;
    /**
     * ```txt
     * "a/"       =>  "a"
     * "index/"   =>  "index"
     * "./a/"     =>  "./a"
     *
     * "./index/" =>  "./index/"
     * ```
     */
    const parts = str.split('/');
    (0, condition_1.assertTrue)(parts.length > 1);
    const prev = parts[parts.length - 2];
    if (parts.length > 2 && PATTERNS.includes(prev))
        return str;
    return str.substr(0, str.length - 1);
}
exports.removeLastSlash = removeLastSlash;
// Exported for testing purpose.
function removeLastIndex(str) {
    if (!str)
        return str;
    const parts = str.split('/');
    if (parts.length < 2)
        return str;
    if (!PATTERNS.includes(parts[parts.length - 1]))
        return str;
    /**
     * ```txt
     * "./index"        => "./"
     * "../index"       =>  "../"
     * "./index/index"  =>  "./index/"
     *
     * "index/index"    => "index"
     * ```
     *
     */
    const prev = parts[parts.length - 2];
    if (prev !== '.' && prev !== '..' && (!PATTERNS.includes(prev) || parts.length < 3))
        parts.pop();
    else
        parts[parts.length - 1] = '';
    return parts.join('/') || '/';
}
exports.removeLastIndex = removeLastIndex;
function removeNodeProtocol(str) {
    return str.startsWith(NODE_PROTOCOL) ? str.slice(NODE_PROTOCOL.length) : str;
}
exports.removeNodeProtocol = removeNodeProtocol;
function addNodeProtocol(str) {
    return str.startsWith(NODE_PROTOCOL) ? str : NODE_PROTOCOL + str;
}
function apply(str, ...norms) {
    return norms.reduce((r, n) => (Array.isArray(n) ? (n[1] ? fn(n[0], r) : r) : fn(n, r)), str);
}
function fn(f, s) {
    return f ? f(s) : s;
}
//# sourceMappingURL=path.js.map