import { type FlagSymbol, type GroupRule } from '../../config';
import { type ComposeConfig, type ESLintConfigProcessed } from '../config';
import { type ImportNode } from '../parser';
import { type Sorter } from './compare';
type SortImportsBy = Required<GroupRule>['sortImportsBy'];
export default class SortGroup {
    private readonly flags_;
    private readonly regex_;
    private readonly importType_;
    private readonly builtin_;
    private readonly sortImportsBy_;
    private readonly sorter_;
    private readonly subGroups_?;
    private readonly eslintGroupOrder_?;
    private readonly aliasFirst_;
    private nodes_;
    private scripts_;
    private ignoreSubGroups_;
    constructor({ flags: originFlags, regex, importType, builtin, sortImportsBy, sort, subGroups }: GroupRule, parent: {
        sorter: Sorter;
        flags?: FlagSymbol[];
        sortImportsBy?: SortImportsBy;
    }, eslint?: ESLintConfigProcessed);
    /**
     * @param node - The node to be added
     * @param fallBack - Whether to add node if this is a fall-back group
     * @returns Whether node is added to this group
     */
    add(node: ImportNode, fallBack?: boolean): boolean;
    private addToSubGroup;
    /**
     * Sort imports within this group.
     *
     * 1. If `eslintGroupOrder_` is undefined, then sort `nodes_` and `subGroups_`
     *    based on user config.
     * 2. Otherwise:
     *   - If this is the top group (`level === 0`), then:
     *     - Sort `nodes_` (fallback group) based on ESLint and user config.
     *     - Sort `subGroups_` (user config groups) based on their rules.
     *   - If this is the user config group (`level === 1`), then:
     *     - Disregard `subGroups_`.
     *     - Merge all imports together and sort them based on ESLint and user config.
     *   - Else, no sort is needed.
     */
    sort(level?: number): this;
    compose(config: ComposeConfig, sep: string): string;
    private calcSubGroups;
    private get allNodes_();
    /**
     * Infer flags (step 1) from current config (flags) and parent's flags.
     */
    private static inferFlags1;
    /**
     * Infer flags (step 2) from children's flags.
     */
    private static inferFlags2;
}
export {};
