"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sortAndMergeExportNodes = exports.sortImportNodes = exports.mergeImportNodes = void 0;
const compare_1 = require("./compare");
function mergeImportNodes(nodes) {
    const merged = nodes.reduce((r, n) => (r.some(e => e.merge(n)) ? r : [...r, n]), Array());
    merged.forEach(n => {
        if (n.binding?.type === 'named')
            n.binding.names = dedupBindingNames(n.binding.names);
    });
    return merged;
}
exports.mergeImportNodes = mergeImportNodes;
function sortImportNodes(nodes, byPaths, { comparePaths, compareNames }, aliasFirst) {
    // Sort binding names
    nodes.forEach(n => {
        if (n.binding?.type !== 'named')
            return;
        if (compareNames)
            n.binding.names = sortBindingNames(n.binding.names, compareNames, aliasFirst);
        n.checkBindingDefault();
    });
    // Sort imports
    return byPaths
        ? sortImportNodesByPaths(nodes, comparePaths, compareNames)
        : sortImportNodesByNames(nodes, aliasFirst, comparePaths, compareNames);
}
exports.sortImportNodes = sortImportNodes;
function sortAndMergeExportNodes(nodes, compareNames) {
    // For `export { A } from 'a'`, merge to the front.
    const m1 = nodes.reduce((r, n) => (n.hasModuleIdentifier() && r.some(a => a.merge(n)) ? r : [...r, n]), Array());
    // For `export { A }`, merge to the end.
    const m2 = m1
        .reverse()
        .reduce((r, n) => (!n.hasModuleIdentifier() && r.some(a => a.merge(n)) ? r : [...r, n]), Array())
        .reverse();
    if (compareNames)
        m2.forEach(n => (n.names = sortBindingNames(dedupBindingNames(n.names), compareNames, false)));
    return m2;
}
exports.sortAndMergeExportNodes = sortAndMergeExportNodes;
function dedupBindingNames(names) {
    return names.reduce((r, a) => (r.some(e => isEqual(e, a)) ? r : [...r, a]), // Remove duplicates
    new Array());
}
function sortBindingNames(names, compareNames, aliasFirst) {
    return names.sort((a, b) => (0, compare_1.compareBindingName)(a, b, compareNames, aliasFirst));
}
function sortImportNodesByPaths(nodes, comparePaths, compareNames) {
    return comparePaths
        ? nodes.sort((a, b) => (0, compare_1.compareImportNodesByPaths)(a, b, comparePaths, compareNames))
        : nodes;
}
function sortImportNodesByNames(nodes, aliasFirst, comparePaths, compareNames) {
    return compareNames
        ? nodes.sort((a, b) => (0, compare_1.compareImportNodesByNames)(a, b, comparePaths, compareNames, aliasFirst))
        : nodes;
}
function isEqual(a, b) {
    return a.aliasName === b.aliasName && a.propertyName === b.propertyName;
}
//# sourceMappingURL=merge.js.map